* ***************************************
* IMMIGRATION AND SUPPORT FOR WELFARE 
*    IN GERMANY (online appendix)
* Analyzing ALLBUS data 1994, 2000, 2004
*   2010 merged with census data
*   using mixed effects ordered probit 
*   models with decomposition of within
*   and between effects
* Author: Alexander Schmidt
* Date: 04/13/2015	
*****************************************

clear
set more off
************************************
capture log close
log using Analyze_Data_Kreise.log, replace
use data_kreise_complete.dta


		
* generate interaction terms
gen ia_foreign_unemplr = foreign*unemplr		// interaction at context-level
gen foreign_sq = foreign^2
gen ia_foreign_sq_unemplr = foreign_sq*unemplr
		
foreach var of varlist foreign foreign_sq unemplr gdppc ia_foreign_unemplr ia_foreign_sq_unemplr {
bys krs09: egen `var'_m = mean(`var')
gen `var'_dm = `var' - `var'_m
}

* Generate West dummy
recode v5 2=0, gen(west)


* Generate year dummies
tab year, gen(year_)
	rename year_2 y2000
	rename year_3 y2004
	rename year_4 y2010

	

* Analysis 

* individual level variables only (Ref for education is lower secondary = middle category)

oprobit morewel y2000 y2004 y2010 male age married primary higher_secondary employed unemployed leftright ///
income_hh_equiv comsize_2 comsize_3 comsize_4 comsize_5 comsize_6 comsize_7 west, vce(cluster krs09)
est store m1

* add context variables as between and within components
oprobit morewel y2000 y2004 y2010 male age married primary higher_secondary employed unemployed leftright income_hh_equiv comsize_2 comsize_3 comsize_4 comsize_5 comsize_6 comsize_7 west ///
foreign_m foreign_dm unemplr_m unemplr_dm gdppc_m gdppc_dm , vce(cluster krs09)
est store m2

* Different effects depending on the level
oprobit morewel y2000 y2004 y2010 male age married primary higher_secondary employed unemployed leftright income_hh_equiv comsize_2 comsize_3 comsize_4 comsize_5 comsize_6 comsize_7 west ///
foreign_m foreign_sq_m foreign_dm foreign_sq_dm unemplr_m unemplr_dm gdppc_m gdppc_dm , vce(cluster krs09)
est store m3

* make a figure from that
* This marginal effect is calculated for the observed range of foreigners, as should be done in FE Panel Models
capture drop xaxis yaxis*
gen xaxis = .
gen yaxis_pe = .
gen yaxis_lb = .
gen yaxis_ub = .
local i = 0
foreach num of numlist .61(1)26.3 {
local i = `i'+1 
replace xaxis = `num' in `i'
lincom foreign_dm+2*(`num')*foreign_sq_dm
replace yaxis_pe =  r(estimate) in `i'
replace yaxis_lb= r(estimate)-1.96*r(se) in `i'
replace yaxis_ub= r(estimate)+1.96*r(se) in `i'
}
twoway line yaxis_* xaxis, scheme(s1mono) yline(0, lc(black)) legend(off) ytitle("Marginal effect of share of foreigners (in %)") xtitle("Share of foreigners (in %)") ///
lp(solid dash dash) lc(black black black) name(margeff, replace) saving(Figure1_kreise.gph, replace)



* Include interaction at context-level
oprobit morewel y2000 y2004 y2010 male age married primary higher_secondary employed unemployed leftright income_hh_equiv comsize_2 comsize_3 comsize_4 comsize_5 comsize_6 comsize_7 west ///
foreign_m foreign_dm ia_foreign_unemplr_m ia_foreign_unemplr_dm unemplr_m unemplr_dm gdppc_m gdppc_dm , vce(cluster krs09)
est store m4		 



* make a figure from that
* This marginal effect is calculated for the observed range of unemployment rates, as should be done in FE Panel Models
capture drop xaxis yaxis*
gen xaxis = .
gen yaxis_pe = .
gen yaxis_lb = .
gen yaxis_ub = .
local i = 0
foreach num of numlist 3.3(.5)26.3 {
local i = `i'+1 
replace xaxis = `num' in `i'
lincom foreign_dm+(`num')*ia_foreign_unemplr_dm
replace yaxis_pe =  r(estimate) in `i'
replace yaxis_lb= r(estimate)-1.96*r(se) in `i'
replace yaxis_ub= r(estimate)+1.96*r(se) in `i'
}
twoway line yaxis_* xaxis, scheme(s1mono) yline(0, lc(black)) legend(off) ytitle("Marginal effect of share of foreigners (in %)") xtitle("Unemployment rate (in %)") ///
lp(solid dash dash) lc(black black black) saving(Figure2_kreise.gph, replace)


* Include a three way interaction
oprobit morewel y2000 y2004 y2010 male age married primary higher_secondary employed unemployed leftright income_hh_equiv comsize_2 comsize_3 comsize_4 comsize_5 comsize_6 comsize_7 west ///
foreign_m foreign_dm foreign_sq_m foreign_sq_dm ia_foreign_unemplr_m ia_foreign_unemplr_dm ia_foreign_sq_unemplr_m ia_foreign_sq_unemplr_dm unemplr_m unemplr_dm gdppc_m gdppc_dm , vce(cluster krs09)
est store m5		



* make a figure from that
* This marginal effect is calculated for the observed range of unemployment rates, as should be done in FE Panel Models
* as the foreigner effect is nonlinear, I set it to three different values (min/mean/max)

capture drop xaxis yaxis*
gen xaxis = .
gen yaxisFmin_pe = .
gen yaxisFmean_pe = .
gen yaxisFmax_pe = .
gen yaxisFmin_lb = .
gen yaxisFmean_lb = .
gen yaxisFmax_lb = .
gen yaxisFmin_ub = .
gen yaxisFmean_ub = .
gen yaxisFmax_ub = .
local i = 0
foreach num of numlist 3.3(.5)26.3 {
local i = `i'+1 
replace xaxis = `num' in `i'
lincom foreign_dm+2*foreign_sq_dm*(1.57)+ia_foreign_unemplr_dm*(`num')+2*ia_foreign_sq_unemplr_dm*(2.46)*(`num')
replace yaxisFmin_pe =  r(estimate) in `i'
replace yaxisFmin_lb= r(estimate)-1.96*r(se) in `i'
replace yaxisFmin_ub= r(estimate)+1.96*r(se) in `i'
lincom foreign_dm+2*foreign_sq_dm*(7)+ia_foreign_unemplr_dm*(`num')+2*ia_foreign_sq_unemplr_dm*(7.21)*(`num')
replace yaxisFmean_pe =  r(estimate) in `i'
replace yaxisFmean_lb= r(estimate)-1.96*r(se) in `i'
replace yaxisFmean_ub= r(estimate)+1.96*r(se) in `i'
lincom foreign_dm+2*foreign_sq_dm*(12.42)+ia_foreign_unemplr_dm*(`num')+2*ia_foreign_sq_unemplr_dm*(11.96)*(`num')
replace yaxisFmax_pe =  r(estimate) in `i'
replace yaxisFmax_lb= r(estimate)-1.96*r(se) in `i'
replace yaxisFmax_ub= r(estimate)+1.96*r(se) in `i'
}

twoway line yaxis?min*  xaxis, scheme(s1mono) yline(0, lc(black)) legend(off) ytitle("Marginal effect of share of foreigners (in %)") ///
 xtitle("Unemployment rate (in %)") lp(solid dash dash) lc(black black black) saving(Figure3a_kreise.gph, replace) ///
 title("Share of foreigners = min (2.46%)")
twoway line yaxis?mean*  xaxis, scheme(s1mono) yline(0, lc(black)) legend(off) ytitle("Marginal effect of share of foreigners (in %)") ///
 xtitle("Unemployment rate (in %)") lp(solid dash dash) lc(black black black) saving(Figure3b_kreise.gph, replace) ///
 title("Share of foreigners = mean (7.21%)")
twoway line yaxis?max*  xaxis, scheme(s1mono) yline(0, lc(black)) legend(off) ytitle("Marginal effect of share of foreigners (in %)") ///
 xtitle("Unemployment rate (in %)") lp(solid dash dash) lc(black black black) saving(Figure3c_kreise.gph, replace) ///
 title("Share of foreigners = max (11.96%)")

	
est tab m1 m2 m3 m4 m5, star(.05 .01 .001) stats(N aic bic ll)
est tab m1 m2 m3 m4 m5,  stats(N aic bic ll) 
est tab m1 m2 m3 m4 m5, b(%9.4f) se(%9.4f)
********************************

 
 log close
