***********************************
* Analyzing east and west germany in one model
* ordinal probit mixed effects regression with decomposition of within and between effects
* Analyzing ALLBUS data 1994, 2004, 2000, 2010
* Author: Alexander Schmidt
************************************

clear
set more off
************************************
capture log close
log using Analyze_Data_Laender.log, replace
use data_laender_complete.dta


			
* generate interaction terms
gen ia_foreign_unemplr = foreign*unemplr		// interaction at context-level
gen foreign_sq = foreign^2
gen ia_foreign_sq_unemplr = foreign_sq*unemplr
		
foreach var of varlist foreign foreign_sq unemplr gdppc ia_foreign_unemplr ia_foreign_sq_unemplr {
bys land: egen `var'_m = mean(`var')
gen `var'_dm = `var' - `var'_m
}

* Generate West dummy
recode v5 2=0, gen(west)


* Generate year dummies
tab year, gen(year_)
	rename year_2 y2000
	rename year_3 y2004
	rename year_4 y2010

	

* Analysis 



oprobit morewel y2000 y2004 y2010 male age married primary higher_secondary employed unemployed leftright ///
income_hh_equiv comsize_2 comsize_3 comsize_4 comsize_5 comsize_6 comsize_7 west , vce(cluster land)
est store m1

* add context variables as between and within components
oprobit morewel y2000 y2004 y2010 male age married primary higher_secondary employed unemployed leftright income_hh_equiv comsize_2 comsize_3 comsize_4 comsize_5 comsize_6 comsize_7 west ///
foreign_m foreign_dm unemplr_m unemplr_dm gdppc_m gdppc_dm , vce(cluster land)
est store m2

* Different effects depending on the level
oprobit morewel y2000 y2004 y2010 male age married primary higher_secondary employed unemployed leftright income_hh_equiv comsize_2 comsize_3 comsize_4 comsize_5 comsize_6 comsize_7 west ///
foreign_m foreign_sq_m foreign_dm foreign_sq_dm unemplr_m unemplr_dm gdppc_m gdppc_dm , vce(cluster land)
est store m3

* make a figure from that
* This marginal effect is calculated for the observed range of foreigners, as should be done in FE Panel Models
capture drop xaxis yaxis*
gen xaxis = .
gen yaxis_pe = .
gen yaxis_lb = .
gen yaxis_ub = .
local i = 0
foreach num of numlist 1(.5)17.5 {
local i = `i'+1 
replace xaxis = `num' in `i'
lincom foreign_dm+2*(`num')*foreign_sq_dm
replace yaxis_pe =  r(estimate) in `i'
replace yaxis_lb= r(estimate)-1.96*r(se) in `i'
replace yaxis_ub= r(estimate)+1.96*r(se) in `i'
}
twoway line yaxis_* xaxis, scheme(s1mono) yline(0, lc(black)) legend(off) ytitle("Marginal effect of share of foreigners (in %)") xtitle("Share of foreigners (in %)") ///
lp(solid dash dash) lc(black black black) name(margeff, replace) saving(Figure1_kreise.gph, replace)



* Include interaction at context-level
oprobit morewel y2000 y2004 y2010 male age married primary higher_secondary employed unemployed leftright income_hh_equiv comsize_2 comsize_3 comsize_4 comsize_5 comsize_6 comsize_7 west ///
foreign_m foreign_dm ia_foreign_unemplr_m ia_foreign_unemplr_dm unemplr_m unemplr_dm gdppc_m gdppc_dm , vce(cluster land)
est store m4		


* make a figure from that
* This marginal effect is calculated for the observed range of unemployment rates, as should be done in FE Panel Models
capture drop xaxis yaxis*
gen xaxis = .
gen yaxis_pe = .
gen yaxis_lb = .
gen yaxis_ub = .
local i = 0
foreach num of numlist 5.1(.5)22.1 {
local i = `i'+1 
replace xaxis = `num' in `i'
lincom foreign_dm+(`num')*ia_foreign_unemplr_dm
replace yaxis_pe =  r(estimate) in `i'
replace yaxis_lb= r(estimate)-1.96*r(se) in `i'
replace yaxis_ub= r(estimate)+1.96*r(se) in `i'
}
twoway line yaxis_* xaxis, scheme(s1mono) yline(0, lc(black)) legend(off) ytitle("Marginal effect of share of foreigners (in %)") xtitle("Unemployment rate (in %)") ///
lp(solid dash dash) lc(black black black) saving(Figure2_kreise.gph, replace)

	
est tab m1 m2 m3 m4, star(.05 .01 .001) stats(N aic bic ll)
est tab m1 m2 m3 m4,  stats(N aic bic ll) 
est tab m1 m2 m3 m4, b(%9.4f) se(%9.4f)
********************************
 
 log close
