* ***************************************
* IMMIGRATION AND SUPPORT FOR WELFARE 
*    IN GERMANY (Online appendix)
* Matching ALLBUS Data 1994, 2000, 2004 
*   and 2010 with regional context data;
*   preparing variables and sample for 
*   analysis on Kreis-level
* Author: Alexander Schmidt
* Date: 04/13/2015	
*****************************************



set more off
capture log close


*****************************************
log using Prepare_Data_Kreise.log, replace




*****************************************
* Prepare macro-level data
*****************************************
use "makrodaten_kreis_ebene.dta", clear



* unemplyoment rate 2010 (calculating the weighted mean)
rename arbeitslosenquote_2010 unemplr2010 
label variable unemplr2010 "Unemployment Rate 2010"



* uenmployment rate 2004
rename  arbeitslosenquote_2004 unemplr2004
label variable unemplr2004 "Unemployment Rate 2004"

* uemployment rate 2000
rename arbeitslosenquote_2000 unemplr2000 
label variable unemplr2000 "Unemployment Rate 2000"


* unemployment rate 1996
rename arbeitslosenquote_1996 unemplr1994 
label variable unemplr1994 "Unemployment Rate 1994 (1996)"


* Foreign population 2010 (in percent)
rename auslaenderanteil_2010 foreign2010 
label variable foreign2010 "Foreign born population 2010"

* Foreign population 2004 (in percent)
replace auslaenderanteil_2004 = auslaenderanteil_2004*100 		// different scale for macro-level data in 2004 

rename auslaenderanteil_2004  foreign2004 
label variable foreign2004 "Foreign born population 2004"


* Foreign population 2000 (in percent)
rename auslaenderanteil_2000 foreign2000
label variable foreign2000 "Foreign born population 2000"

* Foreign population 1995 (in percent)
rename auslaenderanteil_1995 foreign1994 
label variable foreign1994 "Foreign born population 1994 (1995)"


* GDP/C 2010 (in Euro)
rename bipproeinwohner2010 gdppc2010
label variable gdppc2010 "GDP/C (in Euro) 2010"

* GDP/C 2004 (in Euro)
rename bipproeinwohner2004 gdppc2004
label variable gdppc2004 "GDP/C (in Euro) 2004"

* GDP/C 2000 (in Euro)
rename bipproeinwohner2000 gdppc2000 
label variable gdppc2000 "GDP/C (in Euro) 2000"


* GDP/C 1995 (in Euro)
rename bipproeinwohner1995 gdppc1994 
label variable gdppc1994 "GDP/C (in Euro) 1994 (1995)"



* drop all other variables
keep krs09 krs09name ror08 ror08name unemplr2010 unemplr2004 unemplr2000 unemplr1994 foreign2010 foreign2004 foreign2000 foreign1994 gdppc2010 gdppc2004 gdppc2000 gdppc1994


* save data set in wide format at the level of RORs - used for descriptive statistics
save makro_data_wide_kreise.dta, replace		// this is not the final data set because some more Kreise are omitted


* transform to long format
reshape long unemplr foreign gdppc, i(krs09) j(year)

* No data available for 
reg unemplr foreign gdppc
list krs09 if e(sample) == 0
keep if e(sample)
* 20 observations are dropped here
	
* label data
label variable year "Survey Year"
label variable foreign "Foreign born population (%)"
label variable unemplr "Unemployment rate (%)"
label variable gdppc "GDP/C (in Euro)"

* Harmonize Kreis-IDs
replace krs09 = krs09/1000

save makrodaten_kreis_ebene_final.dta, replace
describe
inspect krs09
list

********************************************
* Prepare individual level data for merging

use "C:\Users\aschmidt\Documents\aschmidt\201504_Schmidt\Daten bereitgestellt\allb94000410regio_zusatz_schmidt_2013_11.dta", clear

* drop all variables except KRS-ID (harmonized version)
keep KKZ_HARM_2009 KKZ_HARM_2009_NAME v2 v4
sort KKZ_HARM_2009 v2 v4

* prepare for merge command
rename KKZ_HARM_2009 krs09
	label variable krs09 "Kreis"
rename v2 year
	label variable year "Survey Year"
	
	
* merge macro-level data to individual IDs
merge m:1 krs09 year using makrodaten_kreis_ebene_final 

		* merged: 12,229
		* not merged: 798 observations not in using data set.
		* not merged: 1,079 observations not in master data set. Kreise that are not represented in ALLBUS

* clean data set		
keep if _merge == 3	
drop KKZ_HARM_2009_NAME _merge

* describe data
describe
inspect
save makrodaten_kreise_respondent_ids.dta, replace

*******************************************
* merge survey data to the file

use "C:\Users\aschmidt\Documents\aschmidt\201504_Schmidt\Daten bereitgestellt\allb94000410_za4574_schmidt.dta", clear

* drop all variables we do not need

keep v1 v2 v4 v5 v6 v19 v151 v164 v177 v178 v179 v200 v201 v202 v203 v205 v206  ///
v211 v244 v245 v246 v247 v248 v249 v250 v251 v252 v253 v254 v255 v257 v258 v259 v260 ///
v261 v262 v263 v264 v265 v266 v267 v268 v269 v270 v271 v272 v273 v275 v276 v278 v279 ///
v280 v281 v282 v283 v284 v285 v286 v287 v288 v289 v291 v290 v292 v293 v294 v295 v296 ///
v297 v298 v299 v300 v301 v302 v303 v304 v305 v306 v307 v308 v309 v310 v311 v312 v313 ///
v314 v315 v316 v431 v439 v554 v556 v563 v564 v566 v567 v568 v569 v583 v584 v585 v607 v683 ///
v686 v687 v688 v704 v705 v706 v707 v710 v711 v712 v728 v723 v722 v737 v832 v887 v962 v988 v991 v1065 ///
v1070 v1072 v1110 v1111 v1112 v1113 v1114 v1115 v1190 v1194 v1466 v1563 v1564 v1565 v1566 v1567 v1568 v596

* prepare for merging
rename v2 year
	label variable year "Survey Year"
	
* merge macro-level data 
merge 1:1 year v4 using makrodaten_kreise_respondent_ids.dta
keep if _merge == 3
drop _merge
	
		
* clean data set
rename v4 PersId
	label variable PersId "Individual ID"
order krs09 PersId year foreign unemplr gdppc	
sort krs09 year PersId


****************************
* prepare data for analysis
***************************


* Exclude Non-Natives from the data file
keep if v6 == 1 & v1072 == 1

* Dependent Variable
drop if v206 == 9		// drop if dependent variable == missing
gen morewel_smallN = v206
	label variable morewel_smallN "Government increase spending (small N)"
	replace morewel_smallN = . if morewel_smallN==0
replace v206 = 2 if v205 == 2
	rename v206 morewel
	label variable morewel "Government should increase social spending"


* Gender
recode v556 2=0
	rename v556 male
	label variable male "Gender(male=1)"

* Age
rename v554 age
	drop if age == 999
	label variable age "Age"
	gen agesq = age^2
	label variable agesq "Age squared"
	
* Married
recode v737 2/6 = 0 
		rename v737 married
		drop if married == 99
		label variable married "Family status = married"

* Education		
recode v563 1 2 = 1 3 = 2 4 5 = 3 else=4
	rename v563 educ
	drop if educ == 4
	label variable educ "Highest educational degree"
	label define educlb 1"no educ/volks/hauptschule" 2"mittlere Reife" 3"(Fach)Hochschulreife"
	label values educ educlb
	tab educ, gen(educ_)
	rename educ_1 primary
	rename educ_2 lower_secondary
	rename educ_3 higher_secondary
	
* Employment Status
drop if v583 == 99
gen emplstat = 1 if v583 < 3
replace emplstat = 1  if v583 == 12
replace emplstat = 2 if v584 == 3
replace emplstat = 3 if v583 == 3 & emplstat==. | v583 == 4 & emplstat == .
	label variable emplstat "Employment Status"
	label define emplstatlb 1"Employed" 2"Unemplyoed" 3"Not in labor force"
	label values emplstat emplstatlb
	tab emplstat, gen(empl_)
	rename empl_1 employed
	rename empl_2 unemployed
	rename empl_3 nilf
	
* Income
rename v707 income_ind
	label variable income_ind "Individual net income"
	recode income_ind 99997 99999= .

rename v712 income_hh
	label variable income_hh "Household net income"
	recode income_hh 99997 99999= .
rename v1190 hhmembers
	label variable hhmembers "Number of household members"
	drop if hhmembers == 99
	gen hhmembers_sqrt = sqrt(hhmembers)

gen income_hh_equiv = income_hh/sqrt(hhmembers)
		label variable income_hh_equiv "Equivalized household inome"
	
* Left-Right
rename v19 leftright
	label variable leftright "Left-Right position"
	drop if leftright == 99
	
* Community size
rename v1110 comsize
	label variable comsize "Community size"
	tab comsize, gen(comsize_)
	drop if comsize == 9
	

* Clean the data set
* Check variables
inspect krs09 PersId year  v5 v6 morewel morewel_smallN male age married educ emplstat leftright income_* comsize foreign unemplr gdppc  v1565 

order  krs09 krs09name PersId year  v5 v6 morewel male age married educ primary lower_secon higher_s emplstat employed unemployed nilf leftright income_* comsize ///
	comsize_1- comsize_7 foreign unemplr gdppc v1565
keep krs09 krs09name PersId year  v5 v6 morewel morewel_smallN male age married educ primary lower_secon higher_s emplstat employed unemployed nilf leftright income_* comsize ///
	comsize_1- comsize_7 foreign unemplr gdppc v1565 
	
* listwise deletion
reg morewel male age married higher_secondary employed unemployed leftright income_hh_equiv comsize_* foreign unemplr gdppc
	keep if e(sample)
		

save data_kreise_complete.dta, replace
log close

		
