* ***************************************
* IMMIGRATION AND SUPPORT FOR WELFARE 
*    IN GERMANY
* Matching ALLBUS Data 1994, 2000, 2004 
*   and 2010 with regional context data;
*   preparing variables and sample for 
*   analysis
* Author: Alexander Schmidt
* Date: 04/13/2015	
*****************************************



set more off
capture log close


*****************************************
log using Prepare_Data.log, replace




*****************************************
* Prepare macro-level data
use "makrodaten_ror_ebene_update.dta", clear



* unemplyoment rate 2010 (calculating the weighted mean)
gen unemplr2010 = .
label variable unemplr2010 "Unemployment Rate 2010"

bys ror08: egen inhabitants_ror_2010 = total(bevoelkerung_2010)
replace unemplr2010 = arbeitslosenquote_2010*bevoelkerung_2010/inhabitants_ror_2010
bys ror08: egen help = total(unemplr2010)
replace unemplr2010 = help
drop help

* uenmployment rate 2004
gen unemplr2004 = .
label variable unemplr2004 "Unemployment Rate 2004"
bys ror08: egen inhabitants_ror_2004 = total(bevoelkerung_2004)
replace unemplr2004 = arbeitslosenquote_2004*bevoelkerung_2004/inhabitants_ror_2004
bys ror08: egen help = total(unemplr2004)
replace unemplr2004 = help
drop help

* uemployment rate 2000
gen unemplr2000 = .
label variable unemplr2000 "Unemployment Rate 2000"

bys ror08: egen inhabitants_ror_2000 = total(bevoelkerung2000)
replace unemplr2000 = arbeitslosenquote_2000*bevoelkerung2000/inhabitants_ror_2000
bys ror08: egen help = total(unemplr2000)
replace unemplr2000 = help
drop help

* unemployment rate 1996
gen unemplr1994 = .
label variable unemplr1994 "Unemployment Rate 1994 (1996)"

bys ror08: egen inhabitants_ror_1994 = total(bevoelkerung_1995)
replace unemplr1994 = arbeitslosenquote_1996*bevoelkerung_1995/inhabitants_ror_1994
bys ror08: egen help = total(unemplr1994)
replace unemplr1994 = help
drop help


* Foreign population 2010
gen foreign2010 = .
label variable foreign2010 "Foreign born population 2010"

replace foreign2010 = auslaenderanteil_2010*bevoelkerung_2010/inhabitants_ror_2010
bys ror08: egen help = total(foreign2010)
replace foreign2010 = help
drop help

* Foreign population 2004
replace auslaenderanteil_2004 = auslaenderanteil_2004*100 		// correcting for different scale of macro-level data in 2004

gen foreign2004 = .
label variable foreign2004 "Foreign born population 2004"

replace foreign2004 = auslaenderanteil_2004*bevoelkerung_2004/inhabitants_ror_2004
bys ror08: egen help = total(foreign2004)
replace foreign2004 = help
drop help


* Foreign population 2000
gen foreign2000 = .
label variable foreign2000 "Foreign born population 2000"

replace foreign2000 = auslaenderanteil_2000*bevoelkerung2000/inhabitants_ror_2000
bys ror08: egen help = total(foreign2000)
replace foreign2000 = help
drop help

* Foreign population 1995
gen foreign1994 = .
label variable foreign1994 "Foreign born population 1994 (1995)"

replace foreign1994 = auslaenderanteil_1995*bevoelkerung_1995/inhabitants_ror_1994
bys ror08: egen help = total(foreign1994)
replace foreign1994 = help
drop help


* GDP/C 2010 (in Euro)
gen gdppc2010 = .
label variable gdppc2010 "GDP/C (in Euro) 2010"

replace gdppc2010 = bipproeinwohner2010*bevoelkerung_2010/inhabitants_ror_2010
bys ror08: egen help = total(gdppc2010)
replace gdppc2010 = help
drop help

* GDP/C 2004 (in Euro)
gen gdppc2004 = .
label variable gdppc2004 "GDP/C (in Euro) 2004"

replace gdppc2004 = bipproeinwohner2004*bevoelkerung_2004/inhabitants_ror_2004
bys ror08: egen help = total(gdppc2004)
replace gdppc2004 = help
drop help

* GDP/C 2000 (in Euro)
gen gdppc2000 = .
label variable gdppc2000 "GDP/C (in Euro) 2000"

replace gdppc2000 = bipproeinwohner2000*bevoelkerung2000/inhabitants_ror_2000
bys ror08: egen help = total(gdppc2000)
replace gdppc2000 = help
drop help

* GDP/C 1995 (in Euro)
gen gdppc1994 = .
label variable gdppc1994 "GDP/C (in Euro) 1994 (1995)"

replace gdppc1994 = bipproeinwohner1995*bevoelkerung_1995/inhabitants_ror_1994
bys ror08: egen help = total(gdppc1994)
replace gdppc1994 = help
drop help



* drop all other variables
keep ror08 ror08name unemplr2010 unemplr2004 unemplr2000 unemplr1994 foreign2010 foreign2004 foreign2000 foreign1994 gdppc2010 gdppc2004 gdppc2000 gdppc1994

* generate an indicator variable that shows how many Kreise/Staedte are in one ROR
bys ror08: gen zahlkreise=_N

* keep only one row per ROR
bys ror08: keep if _n == 1

* save data set in wide format at the level of RORs - used for descriptive statistics
save makro_data_wide.dta, replace		// this is not the final data set because some more RORs are omitted in the analysis


* transform to long format
reshape long unemplr foreign gdppc, i(ror08) j(year)

* No data available for
* Altmark 1994 (foreign population), ror08 = 1501
* Anhalt-Bitterfeld-Wittenberg 1994 (all three macro indicators), ror08 = 1502
* Halle/S. 1994 (foreign population), ror08 = 1503
* Magdeburg 1994 (foreign population), ror08 = 1504

	* delete these cases from the data
	drop if year == 1994 & ror08 == 1501
	drop if year == 1994 & ror08 == 1502
	drop if year == 1994 & ror08 == 1503
	drop if year == 1994 & ror08 == 1504
	
* label data
label variable year "Survey Year"
label variable foreign "Foreign born population (%)"
label variable unemplr "Unemployment rate (%)"
label variable gdppc "GDP/C (in Euro)"

save makrodaten_ror_ebene_final.dta, replace
describe
inspect ror08
list

********************************************
* Prepare individual level data for merging

use "C:\Users\aschmidt\Documents\aschmidt\201504_Schmidt\Daten bereitgestellt\allb94000410regio_zusatz_schmidt_2013_11.dta", clear

* drop all variables except ROR-ID (harmonized version)
keep ROR_HARM_2009 ROR_HARM_2009_NAME v2 v4
sort ROR_HARM_2009 v2 v4

* prepare for merge command
rename ROR_HARM_2009 ror08
	label variable ror08 "ROR08"
rename v2 year
	label variable year "Survey Year"
	
	
* merge macro-level data to individual IDs
merge m:1 ror08 year using makrodaten_ror_ebene_final 

		* merged: 12,831
		* not merged: 196 observations not in using data set. These are the four RORs from above.
		* not merged: 70 observations not in master data set. RORs that are not represented in ALLBUS

* clean data set		
keep if _merge == 3	

compare  ROR_HARM_2009_NAME ror08name	// fits 	
drop ROR_HARM_2009_NAME _merge

* describe data
describe
inspect
save makrodaten_ror_respondent_ids.dta, replace

*******************************
* merge survey data to the file
*******************************

use "C:\Users\aschmidt\Documents\aschmidt\201504_Schmidt\Daten bereitgestellt\allb94000410_za4574_schmidt.dta", clear

* drop all variables we do not need

keep v1 v2 v4 v5 v6 v19 v151 v164 v177 v178 v179 v200 v201 v202 v203 v205 v206  ///
v211 v244 v245 v246 v247 v248 v249 v250 v251 v252 v253 v254 v255 v257 v258 v259 v260 ///
v261 v262 v263 v264 v265 v266 v267 v268 v269 v270 v271 v272 v273 v275 v276 v278 v279 ///
v280 v281 v282 v283 v284 v285 v286 v287 v288 v289 v291 v290 v292 v293 v294 v295 v296 ///
v297 v298 v299 v300 v301 v302 v303 v304 v305 v306 v307 v308 v309 v310 v311 v312 v313 ///
v314 v315 v316 v431 v439 v554 v556 v563 v564 v566 v567 v568 v569 v583 v584 v585 v607 v683 ///
v686 v687 v688 v704 v705 v706 v707 v710 v711 v712 v728 v723 v722 v737 v832 v887 v962 v988 v991 v1065 ///
v1070 v1072 v1110 v1111 v1112 v1113 v1114 v1115 v1190 v1194 v1466 v1563 v1564 v1565 v1566 v1567 v1568 v596

* prepare for merging
rename v2 year
	label variable year "Survey Year"
	
* merge macro-level data 
merge 1:1 year v4 using makrodaten_ror_respondent_ids.dta

	* merged: 12,831
	* not merged 196 observations not in using data set. These are the same RORs as above
keep if _merge == 3
drop _merge
	
		
* clean data set
rename v4 PersId
	label variable PersId "Individual ID"
order ror08 PersId year  foreign unemplr gdppc	
sort ror08 year PersId

****************************
* prepare data for analysis
***************************


* Exclude Non-Natives from the data file
keep if v6 == 1 & v1072 == 1

* Dependent Variable
* v206 (1,557 missings answered "no opinion" in question v205. Can we use the middle category for those without an opinion?)

drop if v206 == 9		// drop if dependent variable == missing
gen morewel_smallN = v206
	label variable morewel_smallN "Government increase spending (small N)"
	replace morewel_smallN = . if morewel_smallN==0
replace v206 = 2 if v205 == 2
	rename v206 morewel
	label variable morewel "Government should increase social spending"


* Gender
recode v556 2=0
	rename v556 male
	label variable male "Gender(male=1)"

* Age
rename v554 age
	drop if age == 999
	label variable age "Age"
	gen agesq = age^2
	label variable agesq "Age squared"
	
* Married
recode v737 2/6 = 0 
		rename v737 married
		drop if married == 99
		label variable married "Family status = married"

* Education
recode v563 1 2 = 1 3 = 2 4 5 = 3 else=4
	rename v563 educ
	drop if educ == 4
	label variable educ "Highest educational degree"
	label define educlb 1"no educ/volks/hauptschule" 2"mittlere Reife" 3"(Fach)Hochschulreife"
	label values educ educlb
	tab educ, gen(educ_)
	rename educ_1 primary
	rename educ_2 lower_secondary
	rename educ_3 higher_secondary
	
* Employment Status
drop if v583 == 99
gen emplstat = 1 if v583 < 3
replace emplstat = 1  if v583 == 12
replace emplstat = 2 if v584 == 3
replace emplstat = 3 if v583 == 3 & emplstat==. | v583 == 4 & emplstat == .
	label variable emplstat "Employment Status"
	label define emplstatlb 1"Employed" 2"Unemplyoed" 3"Not in labor force"
	label values emplstat emplstatlb
	tab emplstat, gen(empl_)
	rename empl_1 employed
	rename empl_2 unemployed
	rename empl_3 nilf
	
* Income
rename v707 income_ind
	label variable income_ind "Individual net income"
	recode income_ind 99997 99999= .

rename v712 income_hh
	label variable income_hh "Household net income"
	recode income_hh 99997 99999= .
rename v1190 hhmembers
	label variable hhmembers "Number of household members"
	drop if hhmembers == 99
	gen hhmembers_sqrt = sqrt(hhmembers)

gen income_hh_equiv = income_hh/sqrt(hhmembers)
		label variable income_hh_equiv "Equivalized household inome"
	
* Left-Right
rename v19 leftright
	label variable leftright "Left-Right position"
	drop if leftright == 99
	
* Community size
rename v1110 comsize
	label variable comsize "Community size"
	tab comsize, gen(comsize_)
	drop if comsize == 9
	



* Clean the data set
* Check variables
inspect ror08 PersId year  v5 v6 morewel morewel_smallN male age married educ emplstat leftright income_* comsize foreign unemplr gdppc  v1565
order  ror08 ror08name PersId year  v5 v6 morewel male age married educ primary lower_secon higher_s emplstat employed unemployed nilf leftright income_* comsize ///
	comsize_1- comsize_7 foreign unemplr gdppc v1565
keep ror08 ror08name PersId year  v5 v6 morewel morewel_smallN male age married educ primary lower_secon higher_s emplstat employed unemployed nilf leftright income_* comsize ///
	comsize_1- comsize_7 foreign unemplr gdppc v1565 
		

		
* listwise deletion and dropping ROR with less than 10 observations
reg morewel male age married higher_secondary employed unemployed leftright income_hh_equiv comsize_* foreign unemplr gdppc
	keep if e(sample)
bys ror08 year: gen number_cases = _N
			label variable number_cases "Number of Cases per ROR-Year"
			tab number_cases		
			gen sample = 1 if number_cases > 9
			keep if sample == 1		
		
save data_complete.dta, replace
******************************
log close

		
